searchData={"items":[{"type":"module","title":"OpenAiClient","doc":"A client for the OpenAI API.\n\nThis client supports all options provided by the `Req` library, as well as additional options:\n- :breaker - a circuit breaker module (default: `ExBreak`)","ref":"OpenAiClient.html"},{"type":"function","title":"OpenAiClient.get/2","doc":"Sends a GET request to the OpenAI API.","ref":"OpenAiClient.html#get/2"},{"type":"function","title":"Examples - OpenAiClient.get/2","doc":"iex> OpenAiClient.get(\"https://api.openai.com/v1/models\")\n    {:ok, %{\"models\" => [%{\"id\" => \"gpt-3.5-turbo\", \"object\" => \"model\", \"created\" => 1646183485, \"name\" => \"gpt-3.5-turbo\"}]}}","ref":"OpenAiClient.html#get/2-examples"},{"type":"function","title":"OpenAiClient.post/2","doc":"Sends a POST request to the OpenAI API.","ref":"OpenAiClient.html#post/2"},{"type":"function","title":"Examples - OpenAiClient.post/2","doc":"iex> OpenAiClient.post(\"https://api.openai.com/v1/chat/completions\",\n    ...> [json: %{model: \"gpt-3.5-turbo\", messages: [%{role: \"system\", content: \"You are a helpful assistant.\"}, %{role: \"user\", content: \"Who won the world series in 2020?\"}]}])\n    {:ok, %{\"id\" => \"chatcmpl-3o4Bz2rawi6wk8c4L8QR4W7eFCDj\", \"object\" => \"chat.completion\", \"created\" => 1646183485, \"model\" => \"gpt-3.5-turbo\", \"choices\" => [%{\"message\" => %{ \"role\" => \"assistant\", \"content\" => \"The Los Angeles Dodgers won the World Series in 2020.\"}, \"finish_reason\" => \"stop\", \"index\" => 0}]}}","ref":"OpenAiClient.html#post/2-examples"},{"type":"extras","title":"OpenAiClient","doc":"# OpenAiClient\n\nOpenAiClient is a client for the OpenAI API. It supports all options provided by\nthe `Req` library, as well as additional options such as a circuit breaker\nmodule (defaults to `ExBreak`) and the OpenAI organization ID.","ref":"readme.html"},{"type":"extras","title":"Installation - OpenAiClient","doc":"The package can be installed by adding `open_ai_client` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:open_ai_client, \"~> 2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - OpenAiClient","doc":"In your `config/runtime.exs` file, you need to set up the OpenAI API key and organization ID:\n\n```elixir\nimport Config\n\nconfig :open_ai_client, :base_url, System.get_env(\"OPENAI_BASE_URL\") || \"https://api.openai.com/v1\",\nconfig :open_ai_client, :openai_api_key, System.get_env(\"OPENAI_API_KEY\") || raise(\"OPENAI_API_KEY is not set\"),\nconfig :open_ai_client, :openai_organization_id, System.get_env(\"OPENAI_ORGANIZATION_ID\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - OpenAiClient","doc":"You can send a POST request to the OpenAI API like this:\n\n```elixir\n{:ok, %Req.Response{} = response} = OpenAiClient.post(\n  \"/chat/completions\", json: %{\n    model: \"gpt-3.5-turbo\",\n    messages: [\n      %{role: \"system\", content: \"You are a helpful assistant.\"},\n      %{role: \"user\", content: \"Who won the world series in 2020?\"}\n    ]\n  }\n)\n```\n\nAnd a GET request like this:\n\n```elixir\n{:ok, %Req.Response{} = response} = OpenAiClient.get(\"/models\")\n```\n\nBecause this is really just a simple wrapper around the `Req` library, see the\n[Req library documentation](https://hexdocs.pm/req) for details on the\n`Req.Response` module returned by these calls.\n\nFind the published documentation for the latest version at:\nhttps://hexdocs.pm/open_ai_client.","ref":"readme.html#usage"}],"content_type":"text/markdown"}